Enum pallet_staking::Error [−][src]
pub enum Error<T> {
Show 23 variants
NotController,
NotStash,
AlreadyBonded,
AlreadyPaired,
EmptyTargets,
DuplicateIndex,
InvalidSlashIndex,
InsufficientBond,
NoMoreChunks,
NoUnlockChunk,
FundedTarget,
InvalidEraToReward,
InvalidNumberOfNominations,
NotSortedAndUnique,
AlreadyClaimed,
IncorrectHistoryDepth,
IncorrectSlashingSpans,
BadState,
TooManyTargets,
BadTarget,
CannotChillOther,
TooManyNominators,
TooManyValidators,
// some variants omitted
}Expand description
Custom dispatch errors of this pallet.
Variants
Not a controller account.
Not a stash account.
Stash is already bonded.
Controller is already paired.
Targets cannot be empty.
Duplicate index.
Slash record index out of bounds.
Cannot have a validator or nominator role, with value less than the minimum defined by
governance (see MinValidatorBond and MinNominatorBond). If unbonding is the
intention, chill first to remove one’s role as validator/nominator.
Can not schedule more unlock chunks.
Can not rebond without unlocking chunks.
Attempting to target a stash that still has funds.
Invalid era to reward.
Invalid number of nominations.
Items are not sorted and unique.
Rewards for this era have already been claimed for this validator.
Incorrect previous history depth input provided.
Incorrect number of slashing spans provided.
Internal state has become somehow corrupted and the operation cannot continue.
Too many nomination targets supplied.
A nomination target was supplied that was blocked or otherwise not a validator.
The user has enough bond and thus cannot be chilled forcefully by an external person.
There are too many nominators in the system. Governance needs to adjust the staking settings to keep things safe for the runtime.
There are too many validators in the system. Governance needs to adjust the staking settings to keep things safe for the runtime.
Implementations