pub struct ActiveEra();Expand description
The active era information, it holds index and start.
The active era is the era being currently rewarded. Validator set of this era must be
equal to SessionInterface::validators.
Warning: Doc-Only
This type is automatically generated, and is doc-only. See the real version in
pallet::ActiveEra.