pub struct CurrentEra();Expand description
The current era index.
This is the latest planned era, depending on how the Session pallet queues the validator set, it might be active or not.
Warning: Doc-Only
This type is automatically generated, and is doc-only. See the real version in
pallet::CurrentEra.