pub struct CurrentPlannedSession();Expand description
The last planned session scheduled by the session pallet.
This is basically in sync with the call to pallet_session::SessionManager::new_session.
Warning: Doc-Only
This type is automatically generated, and is doc-only. See the real version in
pallet::CurrentPlannedSession.