ErasStakersOverview

Struct ErasStakersOverview 

pub struct ErasStakersOverview();
Summary of validator exposure at a given era.

This contains the total stake in support of the validator and their own stake. In addition, it can also be used to get the number of nominators backing this validator and the number of exposure pages they are divided into. The page count is useful to determine the number of pages of rewards that needs to be claimed.

This is keyed first by the era index to allow bulk deletion and then the stash account. Should only be accessed through EraInfo.

Is it removed after Config::HistoryDepth eras. If stakers hasn’t been set or has been removed then empty overview is returned.

Warning: Doc-Only

This type is automatically generated, and is doc-only. See the real version in pallet::ErasStakersOverview.