pub struct SpanSlash();Expand description
Records information about the maximum slash of a stash within a slashing span, as well as how much reward has been paid out.
Warning: Doc-Only
This type is automatically generated, and is doc-only. See the real version in
pallet::SpanSlash.